Hamt

Enum Hamt 

pub enum Hamt<K, V, HamtRef> {
    Empty,
    Leaf(HashBits, K, V),
    Bitmap(Size, Bitmap, Vec<HamtRef>),
    Collision(HashBits, Vec<(K, V)>),
}

Variants



Empty



Leaf(HashBits, K, V)



Bitmap(Size, Bitmap, Vec<HamtRef>)



Collision(HashBits, Vec<(K, V)>)

Implementations

Source

impl<K, V, HamtRef> Hamt<K, V, HamtRef>
where K: Hash + Eq + Clone, V: Clone, HamtRef: Clone + Deref<Target = Hamt<K, V, HamtRef>> + From<Hamt<K, V, HamtRef>>,

pub fn new() -> Self

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn iter(&self) -> Iter<'_, K, V, HamtRef>

Returns a key value iterator.

pub fn keys(&self) -> Keys<'_, K, V, HamtRef>

Returns an iterator that visits every key in an unspecified order.

pub fn values(&self) -> Values<'_, K, V, HamtRef>

Returns an iterator that visits every value in an unspecified order.

pub fn get<Q>(&self, k: &Q) -> Option<&V>
where K: Borrow<Q>, Q: Hash + Eq + ?Sized,

Returns a reference to the value corresponding to the given key, or None if there is no value associated with the key.

pub fn contains_key<Q>(&self, k: &Q) -> bool
where K: Borrow<Q>, Q: Hash + Eq + ?Sized,

Returns true if the map contains the given key.

pub fn insert<Q, R>(&self, k: &Q, v: &R) -> Self
where K: Borrow<Q>, Q: Hash + Eq + ToOwned<Owned = K> + ?Sized, V: Borrow<R>, R: ToOwned<Owned = V> + ?Sized,

pub fn remove<Q>(&self, k: &Q) -> Self
where K: Borrow<Q>, Q: Hash + Eq + ?Sized,

Returns a new map without an entry corresponding to the given key.

pub fn adjust<F, Q>(&self, key: &Q, f: F) -> Self
where F: FnOnce(&V) -> V, K: Borrow<Q>, Q: Hash + Eq + ?Sized,

Modifies the value tied to the given key with the function f. Otherwise, the map returned is identical.

pub fn update<F, Q>(&self, key: &Q, f: F) -> Self
where F: FnOnce(&V) -> Option<V>, K: Borrow<Q>, Q: Hash + Eq + ToOwned<Owned = K> + ?Sized,

Updates the value at the given key using f. If f returns None, then the entry is removed.

pub fn alter<F, Q>(&self, key: &Q, f: F) -> Self
where F: FnOnce(Option<&V>) -> Option<V>, K: Borrow<Q>, Q: Hash + Eq + ToOwned<Owned = K> + ?Sized,

Updates the value at the given key using f as in Self::update. If no value exists for the given key, then f is passed None.